==> MMDMotion-1.1-src.zip: MMDMotion-1.1/src/main/java/jp/sourceforge/mmd/motion/ShadowPose.java <==
/*
 * The MIT License
 *
 * Copyright 2015 nazo.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package jp.sourceforge.mmd.motion;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

/**
 *
 * @author nazo
 */
public class ShadowPose extends Pose{

    /**
     * rgb [0:1]
     */
    public float distance;
    public byte mode;

    public ShadowPose(){
        super();
        nameOfBone="セルフ影";
        distance = 50f;
        mode=1;
    }

    public ShadowPose(ShadowPose p){
        super(p);
        distance=p.distance;
        mode=p.mode;
    }

    static public ShadowPose fromCSV(String line){
        String [] column=CsvSpliter.split(line);
        if(column.length<3)return null;
        ShadowPose p=new ShadowPose();

        p.frame=Integer.parseInt(column[0]);
        p.mode=Byte.parseByte(column[1]);
        p.distance=Float.parseFloat(column[2]);
        return p;
    }

    @Override
    public String toCSV() {
        return frame+","+mode+","+distance+"\n";
    }

    @Override
    protected byte[] toVMD() {
        int i;
        byte [] a;
        ByteBuffer ret=ByteBuffer.allocate(9).order(ByteOrder.LITTLE_ENDIAN);
        ret.putInt(frame);
        ret.put(mode);
        ret.putFloat(distance);
        return ret.array();
    }

    @Override
    @SuppressWarnings({"CloneDoesntCallSuperClone", "CloneDeclaresCloneNotSupported"})
    public Pose clone() {
        return new ShadowPose(this);
    }
    
}

==> MMDMotion-1.3-src.zip: MMDMotion-1.3/src/main/java/jp/sourceforge/mmd/motion/ShadowPose.java <==
/*
 * The MIT License
 *
 * Copyright 2015 nazo.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package jp.sourceforge.mmd.motion;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

/**
 *
 * @author nazo
 */
public class ShadowPose extends Pose{

    /**
     * rgb [0:1]
     */
    public float distance;
    public byte mode;

    public ShadowPose(){
        super();
        nameOfBone="セルフ影";
        distance = 50f;
        mode=1;
    }

    public ShadowPose(ShadowPose p){
        super(p);
        distance=p.distance;
        mode=p.mode;
    }

    static public ShadowPose fromCSV(String line) throws NumberFormatException{
        String [] column=CsvSpliter.split(line);
        if(column.length<3)return null;
        ShadowPose p=new ShadowPose();

        p.frame=Integer.parseInt(column[0]);
        p.mode=Byte.parseByte(column[1]);
        p.distance=Float.parseFloat(column[2]);
        return p;
    }

    @Override
    public String toCSV() {
        return frame+","+mode+","+distance+"\n";
    }

    @Override
    protected byte[] toVMD() {
        int i;
        byte [] a;
        ByteBuffer ret=ByteBuffer.allocate(9).order(ByteOrder.LITTLE_ENDIAN);
        ret.putInt(frame);
        ret.put(mode);
        ret.putFloat(distance);
        return ret.array();
    }

    @Override
    @SuppressWarnings({"CloneDoesntCallSuperClone", "CloneDeclaresCloneNotSupported"})
    public Pose clone() {
        return new ShadowPose(this);
    }
    
}
